@@ -4,10 +4,8 @@ Abstract Wrapper Base.
 Any other wrapper extends this.
 """
 import uuid
-from abc import (
-    ABC,
-    abstractmethod,
-)
+from abc import ABC
+
 
 class QueueWrapper(ABC):
     _queued: bool = True
@@ -18,6 +16,8 @@ class QueueWrapper(ABC):
             self._queued = kwargs['queued']
             del kwargs['queued']
         self._id = uuid.uuid4()
+        self.args = args
+        self.kwargs = kwargs
 
     @property
     def queued(self):
